Session
=======

Session management: store, session objects, and user avatars.

Session
-------

.. automodule:: genro_asgi.session.session
   :members:
   :undoc-members:
   :show-inheritance:

SessionStore
------------

.. automodule:: genro_asgi.session.store
   :members:
   :undoc-members:
   :show-inheritance:

Avatar
------

.. automodule:: genro_asgi.session.avatar
   :members:
   :undoc-members:
   :show-inheritance:
